Kurozumi_QS: Quadratic Spectral Kernel for Consistent Estimate of Long-run...

View source: R/uroot_breaks.R

Kurozumi_QSR Documentation

Quadratic Spectral Kernel for Consistent Estimate of Long-run Variance

Description

Compute the Quadratic Spectral kernel proposed by Kurozumi (2002) to obtains consistent estimate of long-run variance.

Usage

Kurozumi_QS(e)

Arguments

e

data that needs to compute consistent long-run variance, normally, regression residuals.

Value

Return the consistent estimate of long-run variance, Quadratic Spectral kernel proposed by Kurozumi (2002).

Author(s)

Ho Tsung-wu <tsungwu@ntnu.edu.tw>, College of Management, National Taiwan Normal University.

References

Kurozumi, E. (2002) Testing for stationarity with a break. Journal of Econometrics,108(1), 105-127.

Examples

data(macro)
y=macro[,"INF"]
e=y-mean(y)
Kurozumi_QS(e)

COINT documentation built on Nov. 5, 2025, 6:30 p.m.

Related to Kurozumi_QS in COINT...