Select the q for a FMVAR(p,q) for cointegrated regressions.
fmvar_plag(data,
p=1,
lag.max=12,
v=15,
type=c("const","trend","season","all"),
ker_fun="parzen",
aband=0,
filter=0)
The selected order of q: the selected lagged innovation terms to include in the fitted FMVAR(p,q)
The matrix of all lags and the values of four criteria: "AIC(q)", "HQ(q)", "SC(q)", "FPE(q)".
The dependent variables for a VAR system.
The number of lags for dependent variables, as in a standard VAR(p).
The maxum number of lags used to search for optimal q in fmvar(p,q).
Number of autocovariance terms to compute the spectrum at frequency zero, default=15.
The deterministic parts in the regression.
const = intercept;
trend = lnear trend;
season = seasonal dummies, this option requires ts format;
all = all three options, which requires ts format.
Set kernel function to one of the available kernels, default="parzen". See section details below.
Whether to activate the automatic bandwidth selection.
aband=1. To activate.
aband=0. Do not activate.The default.
Whether to use an AR(1) filter to compute the spectrum at frequency zero.
filter=1. To use.
filter=0. Do not use. The default.
Ho Tsung-wu <tsungwu@ntnu.edu.tw>, College of Management, National Taiwan Normal University.
1. Available kernels. Technical details are referred to Brillinger (1981,P.55)
"parzen"=Parzen kernel
"bartlett"=Bartlett kernel
"dchlet"= Dirichlet kernel
"mdchlet"= Modified Dirichlet kernel
"tukham"=Tukey-Hamming kernel
"tukhan"=Tukey-Hanning kernel
"cauchy"=Cauchy kernel
"bohman"=Bohman kernel
"reisz"=Riesz,Bochner kernel
"gw"= Gauss-Weierstrass kernel
"qs"= Andrews (1991) Quadratic-Spectral
These kernels are written for fm.ols procedures, technically different from those used in pp and kpss tests.
2. Andrews (1991) has developed data based (or automatic) bandwidth procedures for computing the spectrum. COINT implements these procedures for the Parzen, Bartlette, Tukey-Hamming, and the Quadratic-Spectral kernels. When aband is active, COINT ignores the value you specify for the band-width parameter and automatically substitutes the data-based value.
3. The aim of the AR(1) filter is to flatten the spectrum of residual around the zero frequency, thereby making it easier to estimate the true spectrum by simple averaging of the periodogram.
Phillips, P. C. B (1995) Fully Modified Least Squares and Vector Autoregression. Econometrica, 63, 1023-1078.
data(macro)
Q=fmvar_plag(macro,
p=1,
v=15,
lag.max=16,type="trend",
ker_fun="parzen")$selection[1]
out=fmvar(macro,p=1,q=Q,v=15,type="trend", ker_fun="parzen")
Run the code above in your browser using DataLab