| sw | R Documentation |
Computes Stock and Watson (1988) common trends statistic for the null hypothesis that the data is a noncointegrated system (after allowing for a p-th order polynomial time trend).
sw(data,p,v=15,ker_fun="parzen",aband=0,filter=0)
data |
Matrix of k-time series variables. |
p |
Order of the time polynomial in the null hypothesis. |
v |
Number of autocovariance terms to compute the spectrum at frequency zero, default=15. |
ker_fun |
Set kernel function to one of the available kernels, default="parzen". See section |
aband |
Whether to activate the automatic bandwidth selection. |
filter |
Whether to use an AR(1) filter to compute the spectrum at frequency zero. |
1. Available kernels. Technical details are referred to Brillinger (1981,P.55)
"parzen"=Parzen kernel
"fejer"=Bartlett kernel
"dchlet"= Dirichlet kernel
"mdchlet"= Modified Dirichlet kernel
"tukham"=Tukey-Hamming kernel
"tukhan"=Tukey-Hanning kernel
"cauchy"=Cauchy kernel
"bohman"=Bohman kernel
"reisz"=Riesz,Bochner kernel
"gw"= Gauss-Weierstrass kernel
"qs"= Andrews (1991) Quadratic-Spectral
These kernels are written for FM procedures, technically different from those used in pp and kpss tests.
2. Andrews (1991) has developed data based (or automatic) bandwidth procedures for computing the spectrum. COINT implements these procedures for the Parzen, Bartlette, Tukey-Hamming, and the Quadratic-Spectral kernels. When aband is active, COINT ignores the value you specify for the band-width parameter and automatically substitutes the data-based value.
3. The aim of the AR(1) filter is to flatten the spectrum of residual around the zero frequency, thereby making it easier to estimate the true spectrum by simple averaging of the periodogram.
sw_stat |
Test statistic. Reject the null of a unit root if the SW statistic < critical value |
sw_cv |
Critical values. |
Ho Tsung-wu <tsungwu@ntnu.edu.tw>, College of Management, National Taiwan Normal University.
Stock, J. & M. K. Watson (1988) Testing for Common Trends. Journal of the American Statistical Association, 83, 1097-1107.
data(macro)
sw(macro,p=1,v=15)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.