Learn R Programming

COINT (version 0.0.2)

Kurozumi_QS: Quadratic Spectral Kernel for Consistent Estimate of Long-run Variance

Description

Compute the Quadratic Spectral kernel proposed by Kurozumi (2002) to obtains consistent estimate of long-run variance.

Usage

Kurozumi_QS(e)

Value

Return the consistent estimate of long-run variance, Quadratic Spectral kernel proposed by Kurozumi (2002).

Arguments

e

data that needs to compute consistent long-run variance, normally, regression residuals.

Author

Ho Tsung-wu <tsungwu@ntnu.edu.tw>, College of Management, National Taiwan Normal University.

References

Kurozumi, E. (2002) Testing for stationarity with a break. Journal of Econometrics,108(1), 105-127.

Examples

Run this code
data(macro)
y=macro[,"INF"]
e=y-mean(y)
Kurozumi_QS(e)

Run the code above in your browser using DataLab