powered by
Compute the Quadratic Spectral kernel proposed by Kurozumi (2002) to obtains consistent estimate of long-run variance.
Kurozumi_QS(e)
Return the consistent estimate of long-run variance, Quadratic Spectral kernel proposed by Kurozumi (2002).
data that needs to compute consistent long-run variance, normally, regression residuals.
Ho Tsung-wu <tsungwu@ntnu.edu.tw>, College of Management, National Taiwan Normal University.
Kurozumi, E. (2002) Testing for stationarity with a break. Journal of Econometrics,108(1), 105-127.
data(macro) y=macro[,"INF"] e=y-mean(y) Kurozumi_QS(e)
Run the code above in your browser using DataLab